@@ -1,7 +1,7 @@
-
 from alerta.models.alert import Alert
 from alerta.webhooks import WebhookBase
 import json
+from dateutil.parser import parse as parse_date
 
 class ElastalertWebhook(WebhookBase):
 
@@ -29,7 +29,11 @@ class ElastalertWebhook(WebhookBase):
             attributes['remedy']=payload.get('remedy','N/A')
             attributes['payload']=str(payload)
             attributes['timestampReceived']=payload.get('@timestamp','N/A')
-            createTime = payload.get('@timestamp','N/A')
+            try:
+                createTime = parse_date(payload.get('@timestamp'))
+            except Exception as e:
+                print("unable to parse @timestamp as createTime")
+                createTime = 'N/A'
             try:
                 origin = payload['kubernetes']['host']
             except Exception as e:
@@ -50,8 +54,9 @@ class ElastalertWebhook(WebhookBase):
             createTime = createTime,
             attributes = attributes,
             environment = environment,
-            type = 'ElastAlertNotification',
-            raw_data = json.dumps(payload)
+            type = "ElastAlertNotification",
+            raw_data = "This is test",
+            rawData = "Second Test"
         #     environment=payload.get('environment', environment),
         #     severity=payload.get('severity', severity),
         #     service=['fail2ban'],
